//@ util help
util.help();

//@ util help, \? [USE:util help]
\? util

//@ util checkForServerUpgrade help
util.help('checkForServerUpgrade');

//@ util checkForServerUpgrade help, \? [USE:util checkForServerUpgrade help]
\? checkForServerUpgrade

//@ util copyInstance help
// WL15298_TSFR_1_1
// WL15298_TSFR_4_4_1
// WL15298_TSFR_5_1_1
util.help('copyInstance');

//@ util copyInstance help, \? [USE:util copyInstance help]
// WL15298_TSFR_1_1
// WL15298_TSFR_4_4_1
// WL15298_TSFR_5_1_1
\? copyInstance

//@ util copySchemas help
// WL15298_TSFR_2_1
// WL15298_TSFR_4_4_1
// WL15298_TSFR_5_1_1
util.help('copySchemas');

//@ util copySchemas help, \? [USE:util copySchemas help]
// WL15298_TSFR_2_1
// WL15298_TSFR_4_4_1
// WL15298_TSFR_5_1_1
\? copySchemas

//@ util copyTables help
// WL15298_TSFR_4_4_1
util.help('copyTables');

//@ util copyTables help, \? [USE:util copyTables help]
// WL15298_TSFR_4_4_1
\? copyTables

// WL13807-TSFR_1_1
//@ util dumpInstance help
util.help('dumpInstance');

//@ util dumpInstance help, \? [USE:util dumpInstance help]
\? dumpInstance

// WL13807-TSFR_2_1
//@ util dumpSchemas help
util.help('dumpSchemas');

//@ util dumpSchemas help, \? [USE:util dumpSchemas help]
\? dumpSchemas

// WL13804-TSFR_6_1
//@ util dumpTables help
util.help('dumpTables');

//@ util dumpTables help, \? [USE:util dumpTables help]
\? dumpTables

// WL13804-TSFR_1_4
//@ util exportTable help
util.help('exportTable');

//@ util exportTable help, \? [USE:util exportTable help]
\? exportTable

//@ util importJson help
util.help('importJson');

//@ util importJson help, \? [USE:util importJson help]
\? importJson

//@ util importTable help
util.help('importTable');

//@ util importTable help, \? [USE:util importTable help]
\? importTable

//@ util loadDump help
util.help('loadDump');

//@ util loadDump help, \? [USE:util loadDump help]
\? loadDump
